pub enum InsertOp {
Append,
Overwrite,
Replace,
}Variants
Append
Appends new rows to the existing table without modifying any
existing rows. This corresponds to the SQL INSERT INTO query.
Overwrite
Overwrites all existing rows in the table with the new rows.
This corresponds to the SQL INSERT OVERWRITE query.
Replace
If any existing rows collides with the inserted rows (typically based
on a unique key or primary key), those existing rows are replaced.
This corresponds to the SQL REPLACE INTO query and its equivalents.
Implementations