pub struct CopyTo {
pub input: Arc<LogicalPlan>,
pub output_url: String,
pub partition_by: Vec<String>,
pub file_type: Arc<dyn FileType>,
pub options: HashMap<String, String>,
pub output_schema: Arc<DFSchema>,
}Expand description
Operator that copies the contents of a database to file(s)
Fields
input: Arc<LogicalPlan>The relation that determines the tuples to write to the output file(s)
output_url: StringThe location to write the file(s)
partition_by: Vec<String>Determines which, if any, columns should be used for hive-style partitioned writes
file_type: Arc<dyn FileType>File type trait
options: HashMap<String, String>SQL Options that can affect the formats
output_schema: Arc<DFSchema>The schema of the output (a single column “count”)
Implementations