pub struct PhysicalExprSimplifier<'a> { /* private fields */ }Expand description
Simplifies physical expressions by applying various optimizations
This can be useful after adapting expressions from a table schema to a file schema. For example, casts added to match the types may potentially be unwrapped.
Implementations
Sourceimpl<'a> PhysicalExprSimplifier<'a>
impl<'a> PhysicalExprSimplifier<'a>
Sourcepub fn new(schema: &'a Schema) -> PhysicalExprSimplifier<'a>
pub fn new(schema: &'a Schema) -> PhysicalExprSimplifier<'a>
Create a new physical expression simplifier
Sourcepub fn simplify(
&self,
expr: Arc<dyn PhysicalExpr>,
) -> Result<Arc<dyn PhysicalExpr>, DataFusionError>
pub fn simplify( &self, expr: Arc<dyn PhysicalExpr>, ) -> Result<Arc<dyn PhysicalExpr>, DataFusionError>
Simplify a physical expression