#[non_exhaustive]pub enum ObjectStoreError {
Generic {
store: &'static str,
source: Box<dyn Error + Send + Sync>,
},
NotFound {
path: String,
source: Box<dyn Error + Send + Sync>,
},
InvalidPath {
source: Error,
},
JoinError {
source: JoinError,
},
NotSupported {
source: Box<dyn Error + Send + Sync>,
},
AlreadyExists {
path: String,
source: Box<dyn Error + Send + Sync>,
},
Precondition {
path: String,
source: Box<dyn Error + Send + Sync>,
},
NotModified {
path: String,
source: Box<dyn Error + Send + Sync>,
},
NotImplemented {
operation: String,
implementer: String,
},
PermissionDenied {
path: String,
source: Box<dyn Error + Send + Sync>,
},
Unauthenticated {
path: String,
source: Box<dyn Error + Send + Sync>,
},
UnknownConfigurationKey {
store: &'static str,
key: String,
},
}Expand description
The deltalake crate is currently just a meta-package shim for deltalake-core
A specialized Error for object store-related errors
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Generic
A fallback error type when no variant matches
Fields
NotFound
Error when the object is not found at given location
InvalidPath
Error for invalid path
JoinError
Error when tokio::spawn failed
NotSupported
Error when the attempted operation is not supported
AlreadyExists
Error when the object already exists
Precondition
Error when the required conditions failed for the operation
NotModified
Error when the object at the location isn’t modified
NotImplemented
Error when an operation is not implemented
Fields
PermissionDenied
Error when the used credentials don’t have enough permission to perform the requested operation
Unauthenticated
Error when the used credentials lack valid authentication
UnknownConfigurationKey
Error when a configuration key is invalid for the store used