pub enum PartitionValue {
Equal(String),
NotEqual(String),
GreaterThan(String),
GreaterThanOrEqual(String),
LessThan(String),
LessThanOrEqual(String),
In(Vec<String>),
NotIn(Vec<String>),
}Expand description
The deltalake crate is currently just a meta-package shim for deltalake-core A Enum used for selecting the partition value operation when filtering a DeltaTable partition.
Variants
Equal(String)
The partition value with the equal operator
NotEqual(String)
The partition value with the not equal operator
GreaterThan(String)
The partition value with the greater than operator
GreaterThanOrEqual(String)
The partition value with the greater than or equal operator
LessThan(String)
The partition value with the less than operator
LessThanOrEqual(String)
The partition value with the less than or equal operator
In(Vec<String>)
The partition values with the in operator
NotIn(Vec<String>)
The partition values with the not in operator