Enum deltalake::SchemaDataType [−][src]
pub enum SchemaDataType {
primitive(String),
struct(SchemaTypeStruct),
array(SchemaTypeArray),
map(SchemaTypeMap),
}Enum with variants for each top level schema data type.
Variants
primitive(String)Variant representing non-array, non-map, non-struct fields. Wrapped value will contain the the string name of the primitive type.
struct(SchemaTypeStruct)Variant representing a struct.
array(SchemaTypeArray)Variant representing an array.
map(SchemaTypeMap)Variant representing a map.