Module kernel

Module kernel 

The deltalake crate is currently just a meta-package shim for deltalake-core Delta Kernel module

The Kernel module contains all the logic for reading and processing the Delta Lake transaction log.

Modules

arrow
Conversions between Delta and Arrow data types
engine
Provides an engine implementation that implements the required traits. The engine can optionally be built into the kernel by setting the default-engine feature flag. See the related module for more information.
error
Error types for Delta Lake operations.
models
Actions are the fundamental unit of work in Delta Lake. Each action performs a single atomic operation on the state of a Delta table. Actions are stored in the _delta_log directory of a Delta table in JSON format. The log is a time series of actions that represent all the changes made to a table.
scalars
Auxiliary methods for dealing with kernel scalars
schema
transaction
Add a commit entry to the Delta Table. This module provides a unified interface for modifying commit behavior and attributes

Structs

Add
Defines an add action
AddCDCFile
Delta AddCDCFile action that describes a parquet CDC data file.
ArrayType
CheckpointMetadata
This action is only allowed in checkpoints following V2 spec. It describes the details about the checkpoint.
CommitInfo
The commitInfo is a fairly flexible action within the delta specification, where arbitrary data can be stored. However the reference implementation as well as delta-rs store useful information that may for instance allow us to be more permissive in commit conflict resolution.
DecimalType
DeletionVectorDescriptor
Defines a deletion vector
DomainMetadata
The domain metadata action contains a configuration (string) for a named metadata domain
EagerSnapshot
A snapshot of a Delta table that has been eagerly loaded into memory.
Invariant
An invariant for a column that is enforced on all writes to a Delta table.
LogDataHandler
Provides semanitc access to the log data.
LogicalFileView
Provides semantic, typed access to file metadata from Delta log replay.
MapType
Metadata
Protocol
Remove
Represents a tombstone (deleted file) in the Delta log.
Scan
ScanBuilder
Builder to scan a snapshot of a table.
Sidecar
The sidecar action references a sidecar file which provides some of the checkpoint’s file actions. This action is only allowed in checkpoints following V2 spec.
Snapshot
A snapshot of a Delta table
StructField
StructType
A struct is used to represent both the top-level schema of the table as well as struct columns that contain nested columns.
TombstoneView
Transaction
Action used by streaming systems to track progress using application-specific versions to enable idempotency.

Enums

Action
ColumnMetadataKey
DataType
Error
IsolationLevel
The isolation level applied during transaction
MetadataValue
PrimitiveType
StorageType
Storage type of deletion vector
TableFeatures
High level table features

Traits

DataCheck
A trait for all kernel types that are used as part of data checking
MetadataExt
Extension trait for Metadata action
RecordBatchStream
Trait for types that stream RecordBatch
StructDataExt
Extension trait for Kernel’s StructData.
StructTypeExt
Trait to add convenience functions to struct type

Functions

cast_record_batch
Cast recordbatch to a new target_schema, by casting each column array
contains_timestampntz
checks if table contains timestamp_ntz in any field including nested fields.
new_metadata
Please don’t use, this API will be leaving shortly!

Type Aliases

DeltaResult
A specialized Result type for Delta Lake operations.
Schema
Type alias for a top level schema
SchemaRef
Schema reference type
SendableRBStream
SendableRecordBatchStream
Trait for a Stream of RecordBatches that can be passed between threads
SendableScanMetadataStream