Module default

Module default 

The Default Engine

The default implementation of Engine is DefaultEngine.

The underlying implementations use asynchronous IO. Async tasks are run on a separate thread pool, provided by the TaskExecutor trait. Read more in the executor module.

Modules

executor
The default engine uses Async IO to read files, but the kernel APIs are all synchronous. Therefore, we need an executor to run the async IO on in the background.
file_stream
filesystem
json
Default Json handler implementation
parquet
Default Parquet handler implementation
stats
Statistics collection for Delta Lake file writes.
storage

Structs

DefaultEngine
DefaultEngineBuilder
Builder for creating DefaultEngine instances.
DefaultTaskExecutor
Represents the default TaskExecutor. The executor is created lazily to avoid unnecessary instantiations.

Functions

build_add_file_metadata
Converts DataFileMetadata into Add action EngineData using the partition values and table root from the provided WriteContext.