pub enum Error {
Show 19 variants
Arrow(ArrowError),
Generic(String),
GenericError {
source: Box<dyn Error + Send + Sync>,
},
Parquet(ParquetError),
ObjectStore(Error),
FileNotFound(String),
MissingColumn(String),
UnexpectedColumnType(String),
MissingData(String),
MissingVersion,
DeletionVector(String),
Schema(String),
InvalidUrl(ParseError),
MalformedJson(Error),
MissingMetadata,
InvalidInvariantJson {
json_err: Error,
line: String,
},
InvalidGenerationExpressionJson {
json_err: Error,
line: String,
},
MetadataError(String),
Parse(String, DataType),
}Variants
Arrow(ArrowError)
Generic(String)
GenericError
Parquet(ParquetError)
ObjectStore(Error)
FileNotFound(String)
MissingColumn(String)
UnexpectedColumnType(String)
MissingData(String)
MissingVersion
DeletionVector(String)
Schema(String)
InvalidUrl(ParseError)
MalformedJson(Error)
MissingMetadata
InvalidInvariantJson
Error returned when the log contains invalid stats JSON.
Fields
InvalidGenerationExpressionJson
Error returned when the log contains invalid stats JSON.
Fields
MetadataError(String)
Parse(String, DataType)