pub struct Sidecar {
pub file_name: String,
pub size_in_bytes: i64,
pub modification_time: i64,
pub sidecar_type: String,
pub tags: Option<HashMap<String, Option<String>>>,
}Expand description
The sidecar action references a sidecar file which provides some of the checkpoint’s file actions. This action is only allowed in checkpoints following V2 spec.
Fields
file_name: StringThe name of the sidecar file (not a path). The file must reside in the _delta_log/_sidecars directory.
size_in_bytes: i64The size of the sidecar file in bytes
modification_time: i64The time this sidecar file was created, as milliseconds since the epoch.
sidecar_type: StringType of sidecar. Valid values are: “fileaction”. This could be extended in future to allow different kinds of sidecars.
Map containing any additional metadata about the checkpoint sidecar file.