pub struct OptimizeBuilder<'a> { /* private fields */ }Expand description
Optimize a Delta table with given options
If a target file size is not provided then delta.targetFileSize from the
table’s configuration is read. Otherwise a default value is used.
Implementations
Sourceimpl<'a> OptimizeBuilder<'a>
impl<'a> OptimizeBuilder<'a>
Sourcepub fn with_type(self, optimize_type: OptimizeType) -> OptimizeBuilder<'a>
pub fn with_type(self, optimize_type: OptimizeType) -> OptimizeBuilder<'a>
Choose the type of optimization to perform. Defaults to OptimizeType::Compact.
Sourcepub fn with_filters(self, filters: &'a [PartitionFilter]) -> OptimizeBuilder<'a>
pub fn with_filters(self, filters: &'a [PartitionFilter]) -> OptimizeBuilder<'a>
Only optimize files that return true for the specified partition filter
Sourcepub fn with_target_size(self, target: NonZero<u64>) -> OptimizeBuilder<'a>
pub fn with_target_size(self, target: NonZero<u64>) -> OptimizeBuilder<'a>
Set the target file size
Sourcepub fn with_writer_properties(
self,
writer_properties: WriterProperties,
) -> OptimizeBuilder<'a>
pub fn with_writer_properties( self, writer_properties: WriterProperties, ) -> OptimizeBuilder<'a>
Writer properties passed to parquet writer
Sourcepub fn with_commit_properties(
self,
commit_properties: CommitProperties,
) -> OptimizeBuilder<'a>
pub fn with_commit_properties( self, commit_properties: CommitProperties, ) -> OptimizeBuilder<'a>
Additional information to write to the commit
Sourcepub fn with_preserve_insertion_order(
self,
_preserve_insertion_order: bool,
) -> OptimizeBuilder<'a>
👎Deprecated since 0.32.0: compact always keeps partition file order, and z order does not; this setting has no effect
pub fn with_preserve_insertion_order( self, _preserve_insertion_order: bool, ) -> OptimizeBuilder<'a>
compact always keeps partition file order, and z order does not; this setting has no effect
Deprecated. This setting has no effect.
Sourcepub fn with_max_concurrent_tasks(
self,
max_concurrent_tasks: usize,
) -> OptimizeBuilder<'a>
pub fn with_max_concurrent_tasks( self, max_concurrent_tasks: usize, ) -> OptimizeBuilder<'a>
Max number of concurrent tasks
Sourcepub fn with_min_commit_interval(
self,
min_commit_interval: Duration,
) -> OptimizeBuilder<'a>
pub fn with_min_commit_interval( self, min_commit_interval: Duration, ) -> OptimizeBuilder<'a>
Min commit interval
Sourcepub fn with_custom_execute_handler(
self,
handler: Arc<dyn CustomExecuteHandler>,
) -> OptimizeBuilder<'a>
pub fn with_custom_execute_handler( self, handler: Arc<dyn CustomExecuteHandler>, ) -> OptimizeBuilder<'a>
Set a custom execute handler, for pre and post execution
Sourcepub fn with_session_state(
self,
session: Arc<dyn Session>,
) -> OptimizeBuilder<'a>
pub fn with_session_state( self, session: Arc<dyn Session>, ) -> OptimizeBuilder<'a>
Set the DataFusion session used for planning and execution.
The provided session should wrap a concrete datafusion::execution::context::SessionState.
If session is not a SessionState, the default policy is to log a warning and fall back to
internal defaults. To make this strict (error instead), set
with_session_fallback_policy(SessionFallbackPolicy::RequireSessionState).
Example: Arc::new(create_session().state()).
Sourcepub fn with_session_fallback_policy(
self,
policy: SessionFallbackPolicy,
) -> OptimizeBuilder<'a>
pub fn with_session_fallback_policy( self, policy: SessionFallbackPolicy, ) -> OptimizeBuilder<'a>
Control how delta-rs resolves the provided session when it is not a concrete SessionState.
Defaults to SessionFallbackPolicy::InternalDefaults to preserve existing behavior.