DeltaOps

Struct DeltaOps 

pub struct DeltaOps(pub DeltaTable);
👎Deprecated: Use methods directly on DeltaTable instead, e.g. delta_table.create()
The deltalake crate is currently just a meta-package shim for deltalake-core High level interface for executing commands against a DeltaTable

Tuple Fields

0: DeltaTable
👎Deprecated: Use methods directly on DeltaTable instead, e.g. delta_table.create()

Implementations

Source

impl DeltaOps

pub async fn try_from_url(uri: Url) -> Result<DeltaOps, DeltaTableError>

Create a new DeltaOps instance, operating on DeltaTable at given URL.

use deltalake_core::DeltaOps;
use url::Url;

async {
    let url = Url::parse("memory:///").unwrap();
    let ops = DeltaOps::try_from_url(url).await.unwrap();
};
pub async fn try_from_url_with_storage_options( uri: Url, storage_options: HashMap<String, String>, ) -> Result<DeltaOps, DeltaTableError>

Create a DeltaOps instance from URL with storage options

pub fn new_in_memory() -> DeltaOps

Create a new DeltaOps instance, backed by an un-initialized in memory table

Using this will not persist any changes beyond the lifetime of the table object. The main purpose of in-memory tables is for use in testing.

use deltalake_core::DeltaOps;

let ops = DeltaOps::new_in_memory();
pub fn create(self) -> CreateBuilder

👎Deprecated: Use DeltaTable::create instead

Create a new Delta table

use deltalake_core::DeltaOps;

async {
    let ops = DeltaOps::try_from_url(url::Url::parse("memory://").unwrap()).await.unwrap();
    let table = ops.create().with_table_name("my_table").await.unwrap();
    assert_eq!(table.version(), Some(0));
};
pub fn generate(self) -> GenerateBuilder

👎Deprecated: Use DeltaTable::generate instead

Generate a symlink_format_manifest for other engines

pub fn load(self) -> LoadBuilder

👎Deprecated: Use [DeltaTable::scan] instead

Load data from a DeltaTable

pub fn load_cdf(self) -> CdfLoadBuilder

👎Deprecated: Use DeltaTable::scan_cdf instead

Load a table with CDF Enabled

pub fn write( self, batches: impl IntoIterator<Item = RecordBatch>, ) -> WriteBuilder

👎Deprecated: Use DeltaTable::write instead

Write data to Delta table

pub fn vacuum(self) -> VacuumBuilder

👎Deprecated: Use DeltaTable::vacuum instead

Vacuum stale files from delta table

pub fn filesystem_check(self) -> FileSystemCheckBuilder

👎Deprecated: Use DeltaTable::filesystem_check instead

Audit and repair active files with files present on the filesystem

pub fn optimize<'a>(self) -> OptimizeBuilder<'a>

👎Deprecated: Use DeltaTable::optimize instead

Audit active files with files present on the filesystem

pub fn delete(self) -> DeleteBuilder

👎Deprecated: Use DeltaTable::delete instead

Delete data from Delta table

pub fn update(self) -> UpdateBuilder

👎Deprecated: Use DeltaTable::update instead

Update data from Delta table

pub fn restore(self) -> RestoreBuilder

👎Deprecated: Use DeltaTable::restore instead

Restore delta table to a specified version or datetime

pub fn merge<E>(self, source: DataFrame, predicate: E) -> MergeBuilder
where E: Into<Expression>,

👎Deprecated: Use DeltaTable::merge instead

Update data from Delta table

pub fn add_constraint(self) -> ConstraintBuilder

👎Deprecated: Use DeltaTable::add_constraint instead

Add a check constraint to a table

pub fn add_feature(self) -> AddTableFeatureBuilder

👎Deprecated: Use DeltaTable::add_feature instead

Enable a table feature for a table

pub fn drop_constraints(self) -> DropConstraintBuilder

👎Deprecated: Use DeltaTable::drop_constraints instead

Drops constraints from a table

pub fn set_tbl_properties(self) -> SetTablePropertiesBuilder

👎Deprecated: Use DeltaTable::set_tbl_properties instead

Set table properties

pub fn add_columns(self) -> AddColumnBuilder

👎Deprecated: Use DeltaTable::add_columns instead

Add new columns

pub fn update_field_metadata(self) -> UpdateFieldMetadataBuilder

👎Deprecated: Use DeltaTable::update_field_metadata instead

Update field metadata

pub fn update_table_metadata(self) -> UpdateTableMetadataBuilder

👎Deprecated: Use DeltaTable::update_table_metadata instead

Update table metadata