pub struct DeltaOps(pub DeltaTable);delta_table.create()Expand description
The deltalake crate is currently just a meta-package shim for deltalake-core High level interface for executing commands against a DeltaTable
Tuple Fields
0: DeltaTabledelta_table.create()Implementations
Sourceimpl DeltaOps
impl DeltaOps
Sourcepub async fn try_from_url(uri: Url) -> Result<DeltaOps, DeltaTableError>
pub async fn try_from_url(uri: Url) -> Result<DeltaOps, DeltaTableError>
Create a new DeltaOps instance, operating on DeltaTable at given URL.
use deltalake_core::DeltaOps;
use url::Url;
async {
let url = Url::parse("memory:///").unwrap();
let ops = DeltaOps::try_from_url(url).await.unwrap();
};Sourcepub async fn try_from_url_with_storage_options(
uri: Url,
storage_options: HashMap<String, String>,
) -> Result<DeltaOps, DeltaTableError>
pub async fn try_from_url_with_storage_options( uri: Url, storage_options: HashMap<String, String>, ) -> Result<DeltaOps, DeltaTableError>
Create a DeltaOps instance from URL with storage options
Sourcepub fn new_in_memory() -> DeltaOps
pub fn new_in_memory() -> DeltaOps
Create a new DeltaOps instance, backed by an un-initialized in memory table
Using this will not persist any changes beyond the lifetime of the table object. The main purpose of in-memory tables is for use in testing.
use deltalake_core::DeltaOps;
let ops = DeltaOps::new_in_memory();Sourcepub fn create(self) -> CreateBuilder
👎Deprecated: Use DeltaTable::create instead
pub fn create(self) -> CreateBuilder
DeltaTable::create insteadCreate a new Delta table
use deltalake_core::DeltaOps;
async {
let ops = DeltaOps::try_from_url(url::Url::parse("memory://").unwrap()).await.unwrap();
let table = ops.create().with_table_name("my_table").await.unwrap();
assert_eq!(table.version(), Some(0));
};Sourcepub fn generate(self) -> GenerateBuilder
👎Deprecated: Use DeltaTable::generate instead
pub fn generate(self) -> GenerateBuilder
DeltaTable::generate insteadGenerate a symlink_format_manifest for other engines
Sourcepub fn load(self) -> LoadBuilder
👎Deprecated: Use [DeltaTable::scan] instead
pub fn load(self) -> LoadBuilder
DeltaTable::scan] insteadLoad data from a DeltaTable
Sourcepub fn load_cdf(self) -> CdfLoadBuilder
👎Deprecated: Use DeltaTable::scan_cdf instead
pub fn load_cdf(self) -> CdfLoadBuilder
DeltaTable::scan_cdf insteadLoad a table with CDF Enabled
Sourcepub fn write(
self,
batches: impl IntoIterator<Item = RecordBatch>,
) -> WriteBuilder
👎Deprecated: Use DeltaTable::write instead
pub fn write( self, batches: impl IntoIterator<Item = RecordBatch>, ) -> WriteBuilder
DeltaTable::write insteadWrite data to Delta table
Sourcepub fn vacuum(self) -> VacuumBuilder
👎Deprecated: Use DeltaTable::vacuum instead
pub fn vacuum(self) -> VacuumBuilder
DeltaTable::vacuum insteadVacuum stale files from delta table
Sourcepub fn filesystem_check(self) -> FileSystemCheckBuilder
👎Deprecated: Use DeltaTable::filesystem_check instead
pub fn filesystem_check(self) -> FileSystemCheckBuilder
DeltaTable::filesystem_check insteadAudit and repair active files with files present on the filesystem
Sourcepub fn optimize<'a>(self) -> OptimizeBuilder<'a>
👎Deprecated: Use DeltaTable::optimize instead
pub fn optimize<'a>(self) -> OptimizeBuilder<'a>
DeltaTable::optimize insteadAudit active files with files present on the filesystem
Sourcepub fn delete(self) -> DeleteBuilder
👎Deprecated: Use DeltaTable::delete instead
pub fn delete(self) -> DeleteBuilder
DeltaTable::delete insteadDelete data from Delta table
Sourcepub fn update(self) -> UpdateBuilder
👎Deprecated: Use DeltaTable::update instead
pub fn update(self) -> UpdateBuilder
DeltaTable::update insteadUpdate data from Delta table
Sourcepub fn restore(self) -> RestoreBuilder
👎Deprecated: Use DeltaTable::restore instead
pub fn restore(self) -> RestoreBuilder
DeltaTable::restore insteadRestore delta table to a specified version or datetime
Sourcepub fn merge<E>(self, source: DataFrame, predicate: E) -> MergeBuilderwhere
E: Into<Expression>,
👎Deprecated: Use DeltaTable::merge instead
pub fn merge<E>(self, source: DataFrame, predicate: E) -> MergeBuilderwhere
E: Into<Expression>,
DeltaTable::merge insteadUpdate data from Delta table
Sourcepub fn add_constraint(self) -> ConstraintBuilder
👎Deprecated: Use DeltaTable::add_constraint instead
pub fn add_constraint(self) -> ConstraintBuilder
DeltaTable::add_constraint insteadAdd a check constraint to a table
Sourcepub fn add_feature(self) -> AddTableFeatureBuilder
👎Deprecated: Use DeltaTable::add_feature instead
pub fn add_feature(self) -> AddTableFeatureBuilder
DeltaTable::add_feature insteadEnable a table feature for a table
Sourcepub fn drop_constraints(self) -> DropConstraintBuilder
👎Deprecated: Use DeltaTable::drop_constraints instead
pub fn drop_constraints(self) -> DropConstraintBuilder
DeltaTable::drop_constraints insteadDrops constraints from a table
Sourcepub fn set_tbl_properties(self) -> SetTablePropertiesBuilder
👎Deprecated: Use DeltaTable::set_tbl_properties instead
pub fn set_tbl_properties(self) -> SetTablePropertiesBuilder
DeltaTable::set_tbl_properties insteadSet table properties
Sourcepub fn add_columns(self) -> AddColumnBuilder
👎Deprecated: Use DeltaTable::add_columns instead
pub fn add_columns(self) -> AddColumnBuilder
DeltaTable::add_columns insteadAdd new columns
Sourcepub fn update_field_metadata(self) -> UpdateFieldMetadataBuilder
👎Deprecated: Use DeltaTable::update_field_metadata instead
pub fn update_field_metadata(self) -> UpdateFieldMetadataBuilder
DeltaTable::update_field_metadata insteadUpdate field metadata
Sourcepub fn update_table_metadata(self) -> UpdateTableMetadataBuilder
👎Deprecated: Use DeltaTable::update_table_metadata instead
pub fn update_table_metadata(self) -> UpdateTableMetadataBuilder
DeltaTable::update_table_metadata insteadUpdate table metadata